<p class="centered">
    this was an old high school project of mine that is now in <strong>maintenance mode</strong>, <br> please see <a href="https://sent-web.site/">sent-web</a> for the next generation of this project! 
<hr>