<!DOCTYPE html>
<html>
<head>
    <meta http-equiv="Content-Type" content="text/html; charset=UTF-8">
    <meta http-equiv='cache-control' content='no-cache'>
    <meta http-equiv='expires' content='0'>
    <meta http-equiv='pragma' content='no-cache'>
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <meta name="color-scheme" content="light dark">
    <link rel="icon" href="/img/site-icon.webp" type="image/x-icon">
    <link rel="stylesheet" href="/css/style.css">
    <title>error producing pdf</title>
</head>
<body>
    <h1>error producing pdf</h1>
    <div class="error-box">
        <p><strong>sorry, there was an error generating your pdf.</strong></p>
        <p>please check your input and try again.</p>
    </div>
</body>
</html>
