<!DOCTYPE html>
<html>
<head>
    <meta name="color-scheme" content="light dark">
    <meta http-equiv="refresh" content="0; URL='https://youtu.be/XGxIE1hr0w4'" />
    <title>Art and Assets</title>
</head>
<body>
    <p>If you are not redirected, <a href="https://youtu.be/XGxIE1hr0w4">click here for folder contents</a>.</p>
</body>
</html>
