            <details>
                <summary><strong style="font-size: 1.125rem; text-decoration: underline; text-underline-offset: 0.375rem;">← expand for a brief <emphasis>"how-to"</emphasis> 📖</strong></summary>
                <p>
                <ul>
                    <li>type '#' to indicate that you are starting a new slide and then press ↵ (enter/return) twice.</li>
                    <li>you can add a "slide title" after each '#' to name that portion of your presentation.</li>
                    <ul>
                        <li>a space between "#" and your slide title is required: <br><br> </li>
                        <ul class="no-bullets">
                            <li># [YOUR TITLE GOES HERE]</li>
                        </ul>
                        <br>
                    </ul>
                    <li>type/format text underneath the '#' for the slide contents.</li>
                    <ul>
                        <li>make sure to start typing your slide content two ↵'s ("enter key presses") away from the "#".</li>
                        <li>lists require to be formatted in this manner as well: <br><br> </li>
                        <ul class="no-bullets">
                            <li># slide title <br><br>
                                This is a list <br><br>
                                * item 1 <br>
                                * item 2 <br>
                                * item 3 <br>
                            </li>
                        </ul>
                    </ul>
                </ul>
                <br>
                <p class="centered"> <i>It's highly recommended that you use markdown lists rather than plain text lists</i> </p><br>
                </p>
            </details>
            <br>
