            <details>
                <summary><strong style="font-size: 1.125rem; text-decoration: underline; text-underline-offset: 0.375rem;">← expand for a quick video demo 🎬</strong></summary>
                <p>
                    <video controls>
                        <source src="vids/6iaXPNqAwksiXQnb.webm" type="video/webm">
                        <source src="vids/6iaXPNqAwksiXQnb.mp4" type="video/mp4">
                        <source src="vids/6iaXPNqAwksiXQnb.ogv" type="video/ogg">
                        Your browser does not support modern open-source video implementations 😔.
                    </video>
                </p>
            </details>
            <br>
        </div>
    <br>
