@media screen and (prefers-reduced-motion: no-preference) {@view-transition {navigation: auto;}}body {max-width: 50rem;margin: auto;padding: 0 1rem;margin-bottom: 2rem;font-family: sans-serif, "Noto Color Emoji", "Apple Color Emoji", "Segoe UI Emoji";}pre {white-space: pre-wrap;white-space: -moz-pre-wrap;white-space: -pre-wrap;white-space: -o-pre-wrap;word-wrap: break-word;resize: both;overflow: auto;}h1 {text-align: center;}footer {text-align: center;}img {max-width: 37.5rem;width: 100%;margin: auto;display: block;}img.theme-select {max-width: 12.5rem;width: 100%;margin: auto;display: block;}code {overflow-wrap: break-word;}img[alt="BTC logo"], img[alt="XMR Logo"] {max-width: 1em;max-height: 1em;display: inline;}.centered {text-align: center;}.center-block {text-align: center;display: block;margin-right: auto;margin-left: auto;}table.centered {margin-left: auto;margin-right: auto;}th, td {padding: 1rem;}button {font-size: 1rem;font-family: monospace, "Noto Color Emoji", "Apple Color Emoji", "Segoe UI Emoji";text-align: center;}video {max-width: 100%;max-height: 100%;height: auto;}.video {max-width: 100%;max-height: 100%;height: auto;}ul.no-bullets {list-style-type: none;font-family: monospace, "Noto Color Emoji", "Apple Color Emoji", "Segoe UI Emoji";}summary {cursor: pointer;}#generating-indicator {display: none;position: fixed;top: 0;left: 0;width: 100%;height: 100%;max-width: 100%;max-height: 100%;background-color: rgba(0, 0, 0, 0.8);z-index: 1000;text-align: center;color: white;font-size: 1.75rem;padding-top: 15%;}