<!DOCTYPE html>
<html lang=en>

<head>
    <meta http-equiv="Content-Type" content="text/html; charset=UTF-8">
    <meta http-equiv='cache-control' content='no-cache'>
    <meta http-equiv='expires' content='0'>
    <meta http-equiv='pragma' content='no-cache'>
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <?php include "includes/site-title-and-description.php"; ?>
    <?php include "includes/link-tags-in-head.php"; ?>
    <meta name="color-scheme" content="light dark">
</head>

<body>
    <?php
    include "includes/license-banner.php";
    include "includes/secondary-info.php";
    include "includes/nav-header.php";
    ?>
    <h3>licenses</h3>
    <ul>
        <li> <a href="licenses/mit-kj.php">procrastiSlides license (mit)</a> </li>
        <li> <a href="licenses/gpl2.php"> pandoc's license (gnu gpl v2)</a> </li>
        <li><a href="licenses/LaTeX.php"> The LaTeX Project Public License (1.3)</a></li>
        <li><a href="licenses/mit.php"> SimpleMDE's license (mit)</a></li>
        <li><a href="licenses/isc.php"> suckless sent's license (isc)</a></li>

    </ul>

    <h3>related links</h3>
    <ul>
        <li> <a target="_blank" href="https://pandoc.org/">pandoc.org</a> </li>
        <li>SimpleMDE's <a target="_blank" href="https://github.com/sparksuite/simplemde-markdown-editor">github</a> </li>
        <li> <a target="_blank" href="https://www.latex-project.org/">LaTeX-project.org</a> </li>
        <li>rust <a target="_blank" href="https://github.com/uutils/coreutils/">uutils/coreutils</a> project</li>
    </ul>
    </div>

    <br><br><br>
    <footer>

        <?php include "includes/nav-footer.php"; ?>

    </footer>
</body>

</html>